==> hlw-core-0.0.2-20250427.070122-13-sources.jar: cn/gtmap/hlw/core/dto/sqxx/save/GhxxDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.save;

import lombok.Data;

import java.io.Serializable;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/7 22:08
 * @description 过户信息
 */
@Data
public class GhxxDTO implements Serializable {
    /**主键 */
    private String id;

    /**受理编号*/
    private String slbh;

    /**申请ID*/
    private String sqid;

    /**水过户（0：否，1：是）*/
    private String sgh;

    /**电过户（0：否，1：是）*/
    private String dgh;

    /**气过户（0：否，1：是）*/
    private String qgh;

    /**广电过户（0：否，1：是）*/
    private String gdgh;

    /**网络过户（0：否，1：是）*/
    private String wlgh;

    /**户号类型*/
    private String hhlx;

    /**新户主名称*/
    private String xhzmc;

    /**户主名称*/
    private String hzmc;

    /**水费户号*/
    private String sfhh;

    /**电费户号*/
    private String dfhh;

    /**气费户号*/
    private String qfhh;

    /**广电户号*/
    private String gdhh;

    /**网络户号*/
    private String wlhh;

    /**电费是否欠费（0:否，不欠费，1:是 欠费）*/
    private String dfsfqf;

    /**新户主手机号*/
    private String xhzsjh;

    /**新户主身份证号*/
    private String xhzsfzh;

    /**户主手机号*/
    private String hzsjh;

    /**户主身份证号*/
    private String hzsfzh;

    /**新水费户号*/
    private String xsfhh;

    /**新电费户号*/
    private String xdfhh;

    /**备注*/
    private String bz;

    /**数字电视户号1*/
    private String szdshhi;

    /**数字电视户号2*/
    private String szdshhii;

    /**数字电视户号3*/
    private String szdshhiii;

    /**
     * 有线电视户号1
     */
    private String yxdshhi;

    /**
     * 有线电视户号2
     */
    private String yxdshhii;

    /**
     * 有线电视户号3
     */
    private String yxdshhiii;

    /**
     * 暖气过户（0：否，1：是）
     */
    private String nqgh;

    /**
     * 暖气户号
     */
    private String nqhh;

    /**
     * 打印状态：0未打印，1已打印
     */
    private String dyzt;

    /**
     * 是否峰谷用电(1：是，0：否)
     */
    private String sffgyd;

    /**
     * 是否清算电费（1:是，0：否）
     */
    private String sfqsdf;

    /**
     * 电欠费金额(元)
     */
    private Double dqfje;

    /**
     * 水欠费金额(元)
     */
    private Double sqfje;

    /**
     * 气欠费金额(元)
     */
    private Double qqfje;

    /**
     * 水审核部门id
     */
    private String sshbmid;

    /**
     * 水审核部门名称
     */
    private String sshbmmc;

    /**
     * 电审核部门id
     */
    private String dshbmid;

    /**
     * 电审核部门名称
     */
    private String dshbmmc;

    /**
     * 气审核部门id
     */
    private String qshbmid;

    /**
     * 气审核部门名称
     */
    private String qshbmmc;


    /**
     * 原户余额处理(1:转至新用户,0:退回原户主)
     */
    private String yecl;

    /**
     * 原户主收款账号
     */
    private String skzh;

    /**
     * 开户银行
     */
    private String khyh;
}

==> hlw-core-0.0.2-20251023.055425-161-sources.jar: cn/gtmap/hlw/core/dto/sqxx/save/GhxxDTO.java <==
package cn.gtmap.hlw.core.dto.sqxx.save;

import lombok.Data;

import java.io.Serializable;

/**
 * @author <a href="mailto:wangxuebiao@gtmap.cn">wangxuebiao</a>
 * @version 2023/6/7 22:08
 * @description 过户信息
 */
@Data
public class GhxxDTO implements Serializable {
    /**
     * 主键
     */
    private String id;

    /**
     * 受理编号
     */
    private String slbh;

    /**
     * 申请ID
     */
    private String sqid;

    /**
     * 水过户（0：否，1：是）
     */
    private String sgh;

    /**
     * 电过户（0：否，1：是）
     */
    private String dgh;

    /**
     * 气过户（0：否，1：是）
     */
    private String qgh;

    /**
     * 广电过户（0：否，1：是）
     */
    private String gdgh;

    /**
     * 网络过户（0：否，1：是）
     */
    private String wlgh;

    /**
     * 户号类型
     */
    private String hhlx;

    /**
     * 新户主名称
     */
    private String xhzmc;

    /**
     * 户主名称
     */
    private String hzmc;

    /**
     * 水费户号
     */
    private String sfhh;

    /**
     * 电费户号
     */
    private String dfhh;

    /**
     * 气费户号
     */
    private String qfhh;

    /**
     * 广电户号
     */
    private String gdhh;

    /**
     * 网络户号
     */
    private String wlhh;

    /**
     * 电费是否欠费（0:否，不欠费，1:是 欠费）
     */
    private String dfsfqf;

    /**
     * 新户主手机号
     */
    private String xhzsjh;

    /**
     * 新户主身份证号
     */
    private String xhzsfzh;

    /**
     * 户主手机号
     */
    private String hzsjh;

    /**
     * 户主身份证号
     */
    private String hzsfzh;

    /**
     * 新水费户号
     */
    private String xsfhh;

    /**
     * 新电费户号
     */
    private String xdfhh;

    /**
     * 备注
     */
    private String bz;

    /**
     * 数字电视户号1
     */
    private String szdshhi;

    /**
     * 数字电视户号2
     */
    private String szdshhii;

    /**
     * 数字电视户号3
     */
    private String szdshhiii;

    /**
     * 有线电视户号1
     */
    private String yxdshhi;

    /**
     * 有线电视户号2
     */
    private String yxdshhii;

    /**
     * 有线电视户号3
     */
    private String yxdshhiii;

    /**
     * 暖气过户（0：否，1：是）
     */
    private String nqgh;

    /**
     * 暖气户号
     */
    private String nqhh;

    /**
     * 打印状态：0未打印，1已打印
     */
    private String dyzt;

    /**
     * 是否峰谷用电(1：是，0：否)
     */
    private String sffgyd;

    /**
     * 是否清算电费（1:是，0：否）
     */
    private String sfqsdf;

    /**
     * 电欠费金额(元)
     */
    private Double dqfje;

    /**
     * 水欠费金额(元)
     */
    private Double sqfje;

    /**
     * 气欠费金额(元)
     */
    private Double qqfje;

    /**
     * 水审核部门id
     */
    private String sshbmid;

    /**
     * 水审核部门名称
     */
    private String sshbmmc;

    /**
     * 电审核部门id
     */
    private String dshbmid;

    /**
     * 电审核部门名称
     */
    private String dshbmmc;

    /**
     * 气审核部门id
     */
    private String qshbmid;

    /**
     * 气审核部门名称
     */
    private String qshbmmc;


    /**
     * 原户余额处理(1:转至新用户,0:退回原户主)
     */
    private String yecl;

    /**
     * 原户主收款账号
     */
    private String skzh;

    /**
     * 开户银行
     */
    private String khyh;

    /**
     * 过户扩展json
     */
    private String ghKzJson;
}
